ipsec up 6in6
../../guestbin/ping-once.sh --up -I 2001:db8:0:1::254 2001:db8:0:2::254
